Matchings — Map of Objects

Skip to main content
`Ctrl`+`K`

# Matchings

solve_matching_matrices(matrix_1, matrix_2, length, inner_distance) → float

  Computes the minimal distance between two matrices.

  Parameters:

    - matrix_1 – First square matrix.

    - matrix_2 – Second square matrix.

    - length – Length of the matrix.

    - inner_distance – The inner distance (like L1 or L2).

  Returns:

    Objective value

  Return type:

    float

solve_matching_vectors(cost_table) -> (<class 'float'>, <class 'list'>)

  Computes linear sum assignment.

  Parameters:

    cost_table – Cost table.

  Returns:

    Objective value, Optimal matching

  Return type:

    (float, list)